==> cppad-20100101.4.gpl.tgz: cppad-20100101.4/doc/_wishlist_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'wishlist.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'library.xml',
'example.xml',
'configure.xml',
'appendix.xml'
];
var list_down1 = [
'faq.xml',
'speed.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'include_deprecated.xml',
'license.xml'
];
var list_current0 = [
'wishlist.xml#Atan2',
'wishlist.xml#BenderQuad',
'wishlist.xml#CondExp',
'wishlist.xml#Exceptions',
'wishlist.xml#Ipopt',
'wishlist.xml#Library',
'wishlist.xml#Multiple Arguments',
'wishlist.xml#Numeric Limits',
'wishlist.xml#Operation Sequence',
'wishlist.xml#Optimization',
'wishlist.xml#Optimization.Expression Hashing',
'wishlist.xml#Optimization.Microsoft Compiler',
'wishlist.xml#Optimization.Remove Operations From Tape',
'wishlist.xml#Scripting Languages',
'wishlist.xml#Software Guidelines',
'wishlist.xml#Software Guidelines.Boost',
'wishlist.xml#Sparse Jacobians and Hessians',
'wishlist.xml#Sparsity Patterns',
'wishlist.xml#Speed Testing',
'wishlist.xml#Tan and Tanh',
'wishlist.xml#Tracing',
'wishlist.xml#VecAD',
'wishlist.xml#Vector Element Type'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad-20110101.3.gpl.tgz: cppad-20110101.3/doc/_wishlist_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'wishlist.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'library.xml',
'cppad_ipopt_nlp.xml',
'example.xml',
'configure.xml',
'appendix.xml'
];
var list_down1 = [
'faq.xml',
'speed.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'include_deprecated.xml',
'license.xml'
];
var list_current0 = [
'wishlist.xml#Atan2',
'wishlist.xml#BenderQuad',
'wishlist.xml#CondExp',
'wishlist.xml#Ipopt',
'wishlist.xml#Library',
'wishlist.xml#Multiple Arguments',
'wishlist.xml#Numeric Limits',
'wishlist.xml#Operation Sequence',
'wishlist.xml#Optimization',
'wishlist.xml#Optimization.Expression Hashing',
'wishlist.xml#Optimization.Microsoft Compiler',
'wishlist.xml#Software Guidelines',
'wishlist.xml#Software Guidelines.Boost',
'wishlist.xml#Sparsity Patterns',
'wishlist.xml#Speed Testing',
'wishlist.xml#Tan and Tanh',
'wishlist.xml#Tracing',
'wishlist.xml#VecAD',
'wishlist.xml#Vector Element Type'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
